"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.fullyDeleteModel = void 0;
var _constants = require("../constants");
var _status = require("./status");
var _store = require("../helpers/store");
const fullyDeleteModel = async params => {
  const {
    context,
    modelId
  } = params;
  const model = await context.cms.getModel(modelId);
  if (model.isPrivate) {
    throw new Error(`Cannot delete private model.`);
  }
  await context.cms.accessControl.ensureCanAccessModel({
    model,
    rwd: "d"
  });
  await context.cms.accessControl.ensureCanAccessEntry({
    model,
    rwd: "w"
  });
  if (!model) {
    throw new Error(`Model "${modelId}" not found.`);
  }
  const storeKey = (0, _store.createStoreKey)(model);
  const result = await context.db.store.getValue(storeKey);
  const taskId = result.data?.task;
  if (taskId) {
    throw new Error(`Model "${modelId}" is already getting deleted. Task id: ${taskId}.`);
  }
  const task = await context.tasks.trigger({
    input: {
      modelId
    },
    definition: _constants.DELETE_MODEL_TASK,
    name: `Fully delete model: ${modelId}`
  });
  await context.db.store.storeValue(storeKey, (0, _store.createStoreValue)({
    ...model,
    identity: context.security.getIdentity(),
    task: task.id
  }));
  return {
    id: task.id,
    status: (0, _status.getStatus)(task.taskStatus),
    total: 0,
    deleted: 0
  };
};
exports.fullyDeleteModel = fullyDeleteModel;

//# sourceMappingURL=fullyDeleteModel.js.map