"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getDeleteModelProgress = void 0;
var _constants = require("../constants");
var _error = require("@webiny/error");
var _status = require("./status");
var _handlerGraphql = require("@webiny/handler-graphql");
var _store = require("../helpers/store");
const getDeleteModelProgress = async params => {
  const {
    context,
    modelId
  } = params;
  let model;
  try {
    model = await context.cms.getModel(modelId);
  } catch (ex) {
    if (ex instanceof _handlerGraphql.NotFoundError === false) {
      throw ex;
    }
    throw new _error.WebinyError({
      message: "Model not found. It must have been deleted already.",
      code: "MODEL_ALREADY_DELETED_FOUND",
      data: {
        model: modelId
      }
    });
  }
  await context.cms.accessControl.ensureCanAccessModel({
    model,
    rwd: "d"
  });
  await context.cms.accessControl.ensureCanAccessEntry({
    model,
    rwd: "w"
  });
  const storeKey = (0, _store.createStoreKey)(model);
  const result = await context.db.store.getValue(storeKey);
  const taskId = result.data?.task;
  if (!taskId) {
    throw new Error(`Model "${modelId}" is not being deleted.`);
  }
  const task = await context.tasks.getTask(taskId);
  if (task?.definitionId !== _constants.DELETE_MODEL_TASK) {
    throw new _error.WebinyError({
      message: `The task which is deleting a model cannot be found.`,
      code: "DELETE_MODEL_TASK_NOT_FOUND",
      data: {
        model: model.modelId,
        task: taskId
      }
    });
  }
  return {
    id: task.id,
    status: (0, _status.getStatus)(task.taskStatus),
    total: task.output?.total || 0,
    deleted: task.output?.deleted || 0
  };
};
exports.getDeleteModelProgress = getDeleteModelProgress;

//# sourceMappingURL=getDeleteModelProgress.js.map